@@ -16,23 +16,20 @@
 """diceware -- rememberable passphrases
 """
 import argparse
-import pkg_resources
 import sys
 import logging
 from errno import ENOENT
 from random import SystemRandom
+from .__about__ import version as __version__
 from diceware.config import get_config_dict
 from diceware.logger import configure
 from diceware.wordlist import (
-    WordList, get_wordlist_path, get_wordlists_dir, get_wordlist_names,
+    WordList, get_wordlist_path, get_wordlist_dirs, get_wordlist_names,
     )
 
-__version__ = pkg_resources.get_distribution('diceware').version
-
 #: Special chars inserted on demand
 SPECIAL_CHARS = r"~!#$%^&*()-=+[]\{}:;" + r'"' + r"'<>?/0123456789"
 
-
 GPL_TEXT = (
     """
     This program is free software: you can redistribute it and/or modify
@@ -55,7 +52,7 @@ def print_version():
     """Output current version and other infos.
     """
     print("diceware %s" % __version__)
-    print("Copyright (C) 2015-2022 Uli Fouquet")
+    print("Copyright (C) 2015-2024 Uli Fouquet")
     print("diceware is based on suggestions of Arnold G. Reinhold.")
     print("See http://diceware.com for details.")
     print("'Diceware' is a trademark of Arnold G Reinhold,"
@@ -63,6 +60,13 @@ def print_version():
     print(GPL_TEXT)
 
 
+def print_wordlist_dirs():
+    """Output all dirs we look up for wordlists.
+    """
+    for entry in get_wordlist_dirs():
+        print(entry)
+
+
 def get_random_sources():
     """Get a dictionary of all entry points called diceware_random_source.
 
@@ -73,10 +77,16 @@ def get_random_sources():
     that provides a `choice(sequence)` method that works like the
     respective method in the standard Python lib `random` module.
     """
+    from .__about__ import random_sources
     result = dict()
-    for entry_point in pkg_resources.iter_entry_points(
-            group="diceware_random_sources"):
-        result.update({entry_point.name: entry_point.load()})
+    for name, spec in random_sources.items():
+        module, func = spec.split(":")
+        module = __import__(module, fromlist=['__name__'], level=0)
+        try:
+            func = getattr(module, func)
+        except AttributeError as exc:
+            raise ImportError(str(exc))
+        result[name] = func
     return result
 
 
@@ -84,12 +94,12 @@ def handle_options(args):
     """Handle commandline options.
     """
     plugins = get_random_sources()
-    random_sources = plugins.keys()
+    rnd_sources = plugins.keys()
     wordlist_names = get_wordlist_names()
     defaults = get_config_dict()
     parser = argparse.ArgumentParser(
         description="Create a passphrase",
-        epilog="Wordlists are stored in %s" % get_wordlists_dir()
+        epilog="Use --show-wordlist-dirs to list directories where you can store custom wordlists."
         )
     parser.add_argument(
         '-n', '--num', default=6, type=int,
@@ -108,17 +118,17 @@ def handle_options(args):
         '-d', '--delimiter', default='',
         help="Separate words by DELIMITER. Empty string by default.")
     parser.add_argument(
-        '-r', '--randomsource', default='system', choices=random_sources,
+        '-r', '--randomsource', default='system', choices=rnd_sources,
         metavar="SOURCE",
         help=(
             "Get randomness from this source. Possible values: `%s'. "
-            "Default: system" % "', `".join(sorted(random_sources))))
+            "Default: system" % "', `".join(sorted(rnd_sources))))
     parser.add_argument(
         '-w', '--wordlist', default=['en_eff'], choices=wordlist_names,
         metavar="NAME", nargs='*',
         help=(
             "Use words from this wordlist. Possible values: `%s'. "
-            "Wordlists are stored in the folder displayed below. "
+            "Wordlists are stored in the folders displayed below. "
             "Default: en_eff" % "', `".join(wordlist_names)))
     realdice_group = parser.add_argument_group(
         "Arguments related to `realdice' randomsource",
@@ -136,7 +146,11 @@ def handle_options(args):
         help='Be verbose. Use several times for increased verbosity.')
     parser.add_argument(
         '--version', action='store_true',
-        help='output version information and exit.',
+        help='Output version information and exit.',
+        )
+    parser.add_argument(
+        '--show-wordlist-dirs', action='store_true',
+        help='Output directories we look up to find wordlists and exit.',
         )
     for plugin in plugins.values():
         if hasattr(plugin, "update_argparser"):
@@ -216,6 +230,9 @@ def main(args=None):
     if options.version:
         print_version()
         raise SystemExit(0)
+    elif options.show_wordlist_dirs:
+        print_wordlist_dirs()
+        raise SystemExit(0)
     try:
         print(get_passphrase(options))
     except (OSError, IOError) as infile_error:
