@@ -15,7 +15,7 @@
 #  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """Sources of randomness.
 
-Please register all sources as entry point in ``setup.py``. Look out for
+Please register all sources as entry point in ``__about__.py``. Look out for
 "SystemRandomSource" for an example.
 
 For developers of interfaces to other sources of randomness: Currently,
@@ -45,21 +45,15 @@ If you want to manage own commandline options with your plugin, you can
 implement a `classmethod` called ``update_argparser(parser)`` which gets
 an `argparse.ArgumentParser` instance  as argument (no pun intended).
 
-Finally, to register the source, add some stanza in `setup.py` of your
-project that looks like::
+Finally, to register the source, add some stanza in `__about__.py`
+that looks like::
 
     # ...
-    setup(
-        # ...
-        entry_points={
-            # console scripts and other entry points...
-            'diceware_random_sources': [
-                'myrandom = mypkg.mymodule:MyRandomSource',
-                'myothersrc = mypkg.mymodule:MyOtherSource',
-            ],
-        },
-        # ...
-    )
+    random_sources' = {
+         # ...
+        'myrandom': 'mypkg.mymodule:MyRandomSource',
+        'myothersrc': 'mypkg.mymodule:MyOtherSource',
+    }
     # ...
 
 Here the `myrandom` and `myothersrc` lines register random sources that
@@ -80,7 +74,7 @@ from random import SystemRandom
 
 input_func = input
 if sys.version[0] < "3":
-    input_func = raw_input  # NOQA  # pragma: no cover
+    input_func = raw_input  # NOQA: F821  # defined in python 2 only.
 
 
 class SystemRandomSource(object):
@@ -141,7 +135,7 @@ class RealDiceRandomSource(object):
         acceptable range and issue an hint about the procedure.
         """
         if num_rolls == 0:
-            raise(ValueError)
+            raise ValueError
         if (self.dice_sides ** num_rolls) < len(sequence):
             print(
                 "Warning: entropy is reduced! Using only first %s of %s "
